@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2009, 2023, Oracle and/or its affiliates.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
@@ -187,6 +187,7 @@
 #define HAVE_ULONG 1
 #define HAVE_U_INT32_T 1
 #define HAVE_STRUCT_TIMESPEC
+#define HAVE_TM_GMTOFF 1
 
 /* Support for tagging symbols with __attribute__((visibility("hidden"))) */
 #define HAVE_VISIBILITY_HIDDEN 1
@@ -231,6 +232,7 @@
 /* #undef IPV6_V6ONLY */
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
+/* #undef APPLE_ARM */
 
 /*
  * From main CMakeLists.txt
@@ -403,15 +405,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 37
+#define MYSQL_VERSION_PATCH 42
 #define MYSQL_VERSION_EXTRA ""
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.37"
+#define PACKAGE_STRING "MySQL Server 5.7.42"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.37"
-#define VERSION "5.7.37"
+#define PACKAGE_VERSION "5.7.42"
+#define VERSION "5.7.42"
 #define PROTOCOL_VERSION 10
 
 /*
